Position

Enum Position 

pub enum Position {
    Top,
    Left,
    Right,
    Bottom,
    TopLeft,
    TopRight,
    BottomLeft,
    BottomRight,
    Middle,
}
Enum that describes a position within a rectangle

The position can be accessed at two levels of granularity: The values of the enum denote the exact position (i.e: BottomLeft) Helper functions help determine wether that position is part of a given border (i.e: BottomLeft is both part of bottom() and left())

Variants



Top



Left



Right



Bottom



TopLeft



TopRight



BottomLeft



BottomRight



Middle

Implementations

Source

impl Position

pub fn top(&self) -> bool

Is it part of the top row?

pub fn left(&self) -> bool

Is it part of the leftmost column?

pub fn right(&self) -> bool

Is it part of the rightmost column?

pub fn bottom(&self) -> bool

Is it part of the bottom row?