pub enum Position {
Top,
Left,
Right,
Bottom,
TopLeft,
TopRight,
BottomLeft,
BottomRight,
Middle,
}Expand description
Enum that describes a position within a rectangle
The position can be accessed at two levels of granularity:
The values of the enum denote the exact position (i.e: BottomLeft)
Helper functions help determine wether that position is part of a given border
(i.e: BottomLeft is both part of bottom() and left())
Variants
Implementations